Skip to contents

LikelihoodBound Generic likelihood boundary calculation function. Used by the coxres, poisres, and logitres objects to calculate likelihood based confidence intervals.

Usage

LikelihoodBound(x, df, curve_control = list(), control = list(), ...)

Arguments

x

result object from a regression, class coxres or poisres

df

a data.table containing the columns of interest

curve_control

a list of control options for the likelihood boundary regression. See the control options vignette for details.

control

list of parameters controlling the convergence, see the control options vignette for details

...

extended for other necessary parameters

Value

returns a summary of the likelihood boundary