Skip to contents

LikelihoodBound.coxres solves the confidence interval for a cox model, starting at the optimum point and iteratively optimizing end-points of intervals.

Usage

# S3 method for class 'coxres'
LikelihoodBound(x, df, curve_control = list(), control = list(), ...)

Arguments

x

result object from a regression, class coxres

df

a data.table containing the columns of interest

curve_control

a list of control options for the likelihood boundary regression. See the control options vignette for details.

control

list of parameters controlling the convergence, see the control options vignette for details

...

can include the named entries for the curve_control list parameter

Value

returns a summary of the likelihood boundary