OMP_Check Called directly from R, checks the omp flag and returns true if omp is enabled
See also
Other Output and Information Functions:
System_Version()
OMP_Check Called directly from R, checks the omp flag and returns true if omp is enabled
Other Output and Information Functions:
System_Version()