Skip to contents

RelativeRisk Generic relative risk calculation function, currently only used by the coxres object, to calculate relative risks for either the last parameter or a custom point.

Usage

RelativeRisk(x, df, ...)

Arguments

x

result object from a regression, class coxres

df

a data.table containing the columns of interest

...

extended for other necessary parameters

See also

Other Predicted Risk and Rate: RelativeRisk.coxres()