Skip to contents

Residual Generic residual calculation function for Poisson results. Note that the Cox residuals are calculated using the various plotting based functions.

Usage

Residual(x, df, ...)

Arguments

x

result object from a regression, class coxres or poisres

df

a data.table containing the columns of interest

...

extended for other necessary parameters