Skip to contents

plotSchoenfeld Generic Schoenfeld residual plotting function, used by the coxres object to calculate Schoenfeld residuals. Currently only returns data that could be plotted.

Usage

plotSchoenfeld(x, df, plot_options, a_n = NULL, ...)

Arguments

x

result object from a regression, class coxres

df

a data.table containing the columns of interest

plot_options

list of parameters controlling the plot options, see the plotting vignette for different options

a_n

list of initial parameter values, used to determine the number of parameters. May be either a list of vectors or a single vector.

...

can include the named entries for the plot_options parameter

Value

returns the data used for plots