Prints a logistic likelihood boundary regression output clearly
Source:R/Utility.R
print.logitresbound.Rdprint.logitresbound uses the list output from a regression, prints off a table of results and summarizes the score and convergence.
Usage
# S3 method for class 'logitresbound'
print(x, ...)See also
Other Output and Information Functions:
System_Version(),
print.caseconres(),
print.coxres(),
print.coxresbound(),
print.logitres(),
print.poisres(),
print.poisresbound()