Learn R Programming

Colossus (version 1.4.3)

print.poisres: Prints a poisson regression output clearly

Description

print.poisres uses the list output from a regression, prints off a table of results and summarizes the score and convergence.

Usage

# S3 method for poisres
print(x, ...)

Value

return nothing, prints the results to console

Arguments

x

result object from a regression, class poisres

...

can include the number of digits, named digit, or an unnamed integer entry assumed to be digits

See Also

Other Output and Information Functions: System_Version(), print.caseconres(), print.coxres(), print.coxresbound(), print.logitres(), print.poisresbound()