Learn R Programming

Colossus (version 1.4.3)

print.poisresbound: Prints a poisson likelihood boundary regression output clearly

Description

print.poisresbound uses the list output from a regression, prints off a table of results and summarizes the score and convergence.

Usage

# S3 method for poisresbound
print(x, ...)

Value

return nothing, prints the results to console

Arguments

x

result object from a regression, class poisresbound

...

can include the number of digits, named digit, or an unnamed integer entry assumed to be digits

See Also

Other Output and Information Functions: System_Version(), print.caseconres(), print.coxres(), print.coxresbound(), print.logitres(), print.poisres()