RelativeRisk Generic relative risk calculation function,
currently only used by the coxres object, to calculate relative risks
for either the last parameter or a custom point.
See also
Other Predicted Risk and Rate:
RelativeRisk.coxres()
RelativeRisk Generic relative risk calculation function,
currently only used by the coxres object, to calculate relative risks
for either the last parameter or a custom point.
Other Predicted Risk and Rate:
RelativeRisk.coxres()