Residual Generic residual calculation function for Poisson
results. Note that the Cox residuals are calculated using the various
plotting based functions.
Residual Generic residual calculation function for Poisson
results. Note that the Cox residuals are calculated using the various
plotting based functions.