Residual.poisres uses user provided data, person-year/event columns, vectors specifying the model,
and options to calculate residuals for a solved Poisson regression
# S3 method for poisres
Residual(
x,
df,
control = list(),
a_n = c(),
pearson = FALSE,
deviance = FALSE,
...
)returns a list of the final results
result object from a regression, class poisres
a data.table containing the columns of interest
list of parameters controlling the convergence, see the Control_Options vignette for details
list of initial parameter values, used to determine the number of parameters. May be either a list of vectors or a single vector.
boolean to calculate pearson residuals
boolean to calculate deviance residuals
can include the named entries for the assign_control list parameter
Other Poisson Wrapper Functions:
EventAssignment.poisres(),
LikelihoodBound.poisres(),
PoisRun(),
PoisRunJoint(),
PoisRunMulti(),
RunPoissonRegression_Omnibus()