Skip to contents

plotRisk Generic risk plotting function. Used by the coxres object to plot the hazard ratios at different levels of individual covariates. Currently only returns data that could be plotted.

Usage

plotRisk(x, df, plot_options, a_n = c(), ...)

Arguments

x

result object from a regression, class coxres

df

a data.table containing the columns of interest

plot_options

list of parameters controlling the plot options, see RunCoxPlots() for different options

a_n

list of initial parameter values, used to determine the number of parameters. May be either a list of vectors or a single vector.

...

can include the named entries for the plot_options parameter